#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ADDS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ADDS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/adds.hpp>

#endif
